@@ -1,7 +1,7 @@
 package Algorithm::Backoff::Exponential;
 
-our $DATE = '2019-06-05'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2019-06-07'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use warnings;
@@ -64,7 +64,7 @@ Algorithm::Backoff::Exponential - Backoff exponentially
 
 =head1 VERSION
 
-This document describes version 0.004 of Algorithm::Backoff::Exponential (from Perl distribution Algorithm-Backoff), released on 2019-06-05.
+This document describes version 0.005 of Algorithm::Backoff::Exponential (from Perl distribution Algorithm-Backoff), released on 2019-06-07.
 
 =head1 SYNOPSIS
 
@@ -104,14 +104,15 @@ This backoff algorithm calculates the next delay as:
  initial_delay * exponent_base ** (attempts-1)
 
 Only the C<initial_delay> is required. C<exponent_base> is 2 by default (binary
-expoential). For the first failure attempt (C<attempts> = 1) the delay equals
+exponential). For the first failure attempt (C<attempts> = 1) the delay equals
 the initial delay. Then it is doubled, quadrupled, and so on (using the default
 exponent base of 2).
 
 There are limits on the number of attempts (`max_attempts`) and total duration
 (`max_actual_duration`).
 
-It is recommended to add a jitter factor, e.g. 0.25 to add some randomness.
+It is recommended to add a jitter factor, e.g. 0.25 to add some randomness to
+avoid "thundering herd problem".
 
 =head1 METHODS
 
@@ -159,6 +160,8 @@ random number between original_delay * (1-jitter_factor) and original_delay *
 (1+jitter_factor). Jitters are usually added to avoid so-called "thundering
 herd" problem.
 
+The jitter will be applied to delay on failure as well as on success.
+
 =item * B<max_actual_duration> => I<ufloat> (default: 0)
 
 Maximum number of seconds for all of the attempts (0 means unlimited).
