@@ -1,7 +1,7 @@
 package Algorithm::Backoff::Fibonacci;
 
-our $DATE = '2019-06-05'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2019-06-07'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use strict;
 use warnings;
@@ -76,7 +76,7 @@ Algorithm::Backoff::Fibonacci - Backoff using Fibonacci sequence
 
 =head1 VERSION
 
-This document describes version 0.004 of Algorithm::Backoff::Fibonacci (from Perl distribution Algorithm-Backoff), released on 2019-06-05.
+This document describes version 0.005 of Algorithm::Backoff::Fibonacci (from Perl distribution Algorithm-Backoff), released on 2019-06-07.
 
 =head1 SYNOPSIS
 
@@ -122,7 +122,8 @@ optional.
 There are limits on the number of attempts (`max_attempts`) and total duration
 (`max_actual_duration`).
 
-It is recommended to add a jitter factor, e.g. 0.25 to add some randomness.
+It is recommended to add a jitter factor, e.g. 0.25 to add some randomness to
+avoid "thundering herd problem".
 
 =head1 METHODS
 
@@ -172,6 +173,8 @@ random number between original_delay * (1-jitter_factor) and original_delay *
 (1+jitter_factor). Jitters are usually added to avoid so-called "thundering
 herd" problem.
 
+The jitter will be applied to delay on failure as well as on success.
+
 =item * B<max_actual_duration> => I<ufloat> (default: 0)
 
 Maximum number of seconds for all of the attempts (0 means unlimited).
